@@ -11,5 +11,5 @@ task4_id = 'bd6076ef-ac2e-45a1-b38c-b5b1d733f63c' # Update your documentation
 if 'milestone_4_p1.txt' in os.listdir('.'):
     errors = get_errors_fails('milestone_4_p1.txt')
     print(errors)
-    if len(errors) == 0:
+    if len(errors) != 0:
         mark_incomplete(task1_id, errors['test_manual_rps_presence'])
\ No newline at end of file
