@@ -1,7 +1,9 @@
 import random
 
+choices = ["Rock", "Paper", "Scissors"]
+
 def get_computer_choice():
-    return random.choice(['Rock', 'Paper', 'Scissors'])
+    return random.choice(choices)
 
 def get_user_choice():
     while True:
